==========================
Connections API Reference
==========================

Connection and client classes for GNTP communication.

See :doc:`core` for the main documentation of these classes.

.. automodule:: gntplib.connections
   :members:
   :show-inheritance:
